@@ -20,11 +20,11 @@ Net::DAVTalk - Interface to talk to DAV servers
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 
 =head1 SYNOPSIS
@@ -274,9 +274,9 @@ sub Request {
   # one is enough
 
   if ($ENV{DEBUGDAV}) {
-    warn "<<<<<<<< " . Data::Dumper::Dumper({method => $Method, uri => $URI, headers => \%Headers, content => $Bytes }) . "\n\n";
-    warn ">>>>>>>> " . Data::Dumper::Dumper($Response) . "\n\n";
-    warn Data::Dumper::Dumper($Self->{ua});
+    warn "<<<<<<<< $Method $URI HTTP/1.1\n$Bytes\n" .
+         ">>>>>>>> $Response->{protocol} $Response->{status} $Response->{reason}\n$Response->{content}\n" .
+         "========\n\n";
   }
 
   if ($Method eq 'REPORT' && $Response->{status} == 403) {
